mouse_follower library
Classes
- MouseFollower
- A widget that adds animated cursor effects to its child within a mouse region.
- MouseFollowerConsumer
-
Drop-in style consumer to mimic
Consumer<MouseFollowerProvider>. - MouseFollowerScope
-
An InheritedNotifier that exposes a
MouseFollowerProviderto descendants. - MouseOnHoverEvent
- A widget that adds animated cursor effects to its child within a mouse region.
- MouseOnHoverEventState
- The state of the MouseOnHoverEvent widget.
- MouseStyle
- A widget representing a specific mouse cursor style.